"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Messages = void 0;
const iFunnyErrorCodes_1 = require("./iFunnyErrorCodes");
function desc(title, description, fallback = ".") {
    return title + (description ? `: ${description}` : fallback);
}
exports.Messages = {
    // Unknown Error
    [iFunnyErrorCodes_1.iFunnyErrorCodes.UnknownError]: (error) => desc("An unknown error occurred", error),
    // Client Setup Errors
    [iFunnyErrorCodes_1.iFunnyErrorCodes.InvalidClient]: (description) => desc("The client is invalid", description),
    [iFunnyErrorCodes_1.iFunnyErrorCodes.InvalidEmail]: (description) => description,
    [iFunnyErrorCodes_1.iFunnyErrorCodes.Unauthorized]: (description) => desc("Client unauthorized to make request", description),
    // Library Errors
    [iFunnyErrorCodes_1.iFunnyErrorCodes.InvalidBasicTokenLength]: (description) => desc("The basic token must be 156 or 112 characters long", description),
    [iFunnyErrorCodes_1.iFunnyErrorCodes.UncaughtAxiosError]: (message) => desc("Uncaught axios error", message),
    // Auth Errors
    [iFunnyErrorCodes_1.iFunnyErrorCodes.InvalidTokenType]: (tokenType) => desc("Invalid token type", tokenType),
    [iFunnyErrorCodes_1.iFunnyErrorCodes.InvalidBasicToken]: (token) => desc("An invalid basic token was provided", token),
    [iFunnyErrorCodes_1.iFunnyErrorCodes.InvalidBearerToken]: (token) => desc("An invalid bearer token was provided", token),
    [iFunnyErrorCodes_1.iFunnyErrorCodes.InvalidGrant]: (description) => desc("Invalid Auth Token", description),
    [iFunnyErrorCodes_1.iFunnyErrorCodes.CaptchaRequired]: (data) => desc("A captcha is required", data.data.captcha_url),
    // User Errors
    [iFunnyErrorCodes_1.iFunnyErrorCodes.InvalidUserId]: (id) => desc("Invalid user id", id),
    [iFunnyErrorCodes_1.iFunnyErrorCodes.UserNotFound]: (description) => description,
    [iFunnyErrorCodes_1.iFunnyErrorCodes.UserUnavailable]: (user) => desc("User unavailable", user),
    [iFunnyErrorCodes_1.iFunnyErrorCodes.UserDeleted]: (user) => desc("User was deleted", user),
};
exports.default = exports.Messages;
//# sourceMappingURL=Messages.js.map