"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Ban = void 0;
const ifunny_api_types_1 = require("@ifunny/ifunny-api-types");
const Base_1 = require("./Base");
/**
 * Represents a Ban on iFunny
 */
class Ban extends Base_1.Base {
    /**
     * @param client The Client instance
     * @param user User or Id of the user that the ban belongs to
     * @param id Id of the ban itself
     * @param payload Payload of the ban if applicable
     */
    constructor(client, user, payload) {
        super(client, payload);
        this._user = user;
        this.payload = payload;
        this.endpoint_url = ifunny_api_types_1.Endpoints.bans(this._user.id, this.id);
    }
    /**
     * Timestamp (in seconds) of when it expires
     */
    get expiresAtTimestamp() {
        let ms = this.get("date_until");
        return typeof ms === "number" ? ms * 1000 : null;
    }
    /**
     * Date object of when the ban expires
     */
    get expiresAt() {
        let ms = this.expiresAtTimestamp;
        return ms ? new Date(ms) : null;
    }
    /**
     * How long (in seconds) until the ban expires
     */
    get expiresInTimestamp() {
        let ms = this.expiresAtTimestamp;
        return ms ? ms - new Date().getTime() : null;
    }
    /**
     * Date object of how much ms is left until the ban expires
     */
    get expiresIn() {
        let ms = this.expiresInTimestamp;
        return ms ? new Date(ms) : null;
    }
    /**
     * The type of the ban
     */
    get type() {
        return this.get("type");
    }
    /**
     * User that the ban belongs to
     */
    get user() {
        return this._user;
    }
}
exports.Ban = Ban;
//# sourceMappingURL=Ban.js.map