import { CachedManager } from "./CachedManager";
import { Client } from "../client/Client";
import { User } from "../structures/User";
/**
 * Manages iFunny Users
 */
export declare class UserManager extends CachedManager<typeof User> {
    constructor(client: Client);
    /**
     * Checks if a nick is available or if it's taken by another user\
     * It's a good idea to check this before signing up or changing your nick
     * @param nick Nick to check availability of
     */
    nickAvailable(nick: string): Promise<boolean>;
    /**
     * Checks if an email is available or if it's taken by another user\
     * It's a good idea to check this before signing up or changing your email
     * @param email Email to check availability of
     */
    emailAvailable(email: string): Promise<boolean>;
    /**
     * Fetches a user by their ID or Nick
     * @param idOrNick Id or nick of the user
     * @param byNick Whether to lookup by nick (Default: false)
     * @param cached Whater to return the cached result (Default: true)
     * @returns
     */
    fetch(idOrNick: string, byNick?: boolean, cached?: boolean): Promise<User | null>;
}
//# sourceMappingURL=UserManager.d.ts.map