import { Base } from "./Base";
import Client from "../client/Client";
import { Creator } from "./Creator";
import { CONTENT_TYPE, APIContent, APIContentData } from "@ifunny/ifunny-api-types";
/**
 * The Base Content that all Content Types will extend
 */
export declare class BaseContent extends Base<APIContent> {
    private _creator;
    constructor(client: Client, payload: APIContent);
    /**
     * This data is typically retrieved by using the content's type as a key for the content.
     * @example
     * content[content.type] // Key isn't always the type
     */
    get data(): APIContentData;
    /**
     * Content background color
     */
    get bgColor(): string;
    /**
     * Can the post be boosted?
     */
    get canBeBoosted(): boolean;
    /**
     * Content url that can be opened in app
     */
    get canonicalUrl(): string;
    /**
     * Copywright information attached to the content
     */
    get copyright(): import("@ifunny/ifunny-api-types").APIContentCopyright;
    /**
     * The creator of the post
     */
    get creator(): Creator | null;
    /**
     * Timestamp of when the content was created
     */
    get createdAtTimestamp(): number;
    /**
     * When the content was created
     */
    get createdAt(): Date;
    /**
     * Not sure what this is
     */
    get fastStart(): boolean;
    /**
     * Title set by iFunny
     */
    get fixedTitle(): string;
    /**
     * The ID of the Content.
     */
    get id(): string;
    /**
     * Was the post removed by iFunny
     */
    get isAbused(): boolean;
    /**
     * Was the post featured
     */
    get isFeatured(): boolean;
    /**
     * Is the Content pinned by the author
     */
    get isPinned(): boolean;
    /**
     * Is the Content republished by the Client
     */
    get isRepublished(): boolean;
    /**
     * Is the Content smiled by the Client
     */
    get isSmiled(): boolean;
    /**
     * Timestamp of when the Content was Featured if it was featured
     */
    get featuredAtTimestamp(): number | null;
    /**
     * When the Content was featured if it was featured
     */
    get featuredAt(): Date | null;
    /**
     * The link of the content that can be opened in iFunny
     */
    get link(): string;
    /**
     * The numbers attached to the Content
     * @alias stats
     */
    get num(): import("@ifunny/ifunny-api-types").APIContentNums;
    /**
     * The numbers attached to the Content
     * @alias num
     */
    get stats(): import("@ifunny/ifunny-api-types").APIContentNums;
    /**
     * Text generated from iFunny's OCR (Optical Character Recognition)
     */
    get ocrText(): string | null;
    /**
     * Does the Content use the Old Watermark
     */
    get oldWatermark(): boolean;
    /**
     * Timestamp of when the Content was published or will publish
     */
    get publishedAtTimestamp(): number;
    /**
     * When the Content was published or will publish
     */
    get publishedAt(): Date;
    /**
     * The risk level of the Content\
     * Default: `1`
     */
    get risk(): number;
    /**
     * The shot status of the content\
     * `approved` - Content can be posted in comments
     * `shot` - Content can't be posted in comments
     * `hardShot` - Content was removed by iFunny and is not viewable
     */
    get shotStatus(): "approved" | "hardShot" | "shot";
    /**
     * The size of the Content
     */
    get size(): import("@ifunny/ifunny-api-types").Size;
    /**
     * The source of the content if it exists
     */
    get source(): import("@ifunny/ifunny-api-types").APIContentSource | null;
    /**
     * The state of the Content
     */
    get state(): "published" | "delayed";
    /**
     * All tags on the Content
     */
    get tags(): string[];
    /**
     * Thumbnail of the Content
     */
    get thumbnail(): import("@ifunny/ifunny-api-types").APIContentThumbnail;
    /**
     * The Title of the content
     */
    get title(): string;
    /**
     * URL of the original source if it exists
     */
    get tracebackUrl(): string | null;
    /**
     * The type of the post
     */
    get type(): CONTENT_TYPE;
    /**
     * URL of the Content
     */
    get url(): string;
    /**
     * The Content's visibility status\
     * `public` - Content shows up in collective and explore
     * `subscribers` - Content is hidden from Collective and Explore
     * `closed` - Content is not visible by anyone but the author
     */
    get visibility(): "closed" | "public" | "subscribers";
}
//# sourceMappingURL=BaseContent.d.ts.map